HttpError class

Inheritance

Constructors

HttpError({required int statusCode, required String url, String? statusMessage, String? bodyJson, StackTrace? stackTrace, Exception? cause})

Properties

bodyJson String?
final
cause Exception?
finalinherited
code String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited
statusCode int
final
statusMessage String?
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited